from pathlib import Path
import re

from pkg_resources import Requirement
from setuptools import find_packages
from setuptools import setup


_COMMENT_RE = re.compile(r'(^|\s)+#.*$')


def _get_requirements(file_path):
    if isinstance(file_path, str):
        file_path = Path(file_path)
    if not file_path.is_absolute():
        file_path = Path(__file__).parent.joinpath(file_path)

    with open(file_path, 'r') as file:
        for line in file:
            line = _COMMENT_RE.sub('', line)
            line = line.strip()
            if line.startswith('-r '):
                for req in _get_requirements(
                    Path(file_path).parent.joinpath(line[3:])
                ):
                    yield req
            elif line:
                req = Requirement(line)
                req_str = req.name + str(req.specifier)
                if req.marker:
                    req_str += '; ' + str(req.marker)
                yield req_str


def _read(file_path):
    with open(file_path, 'r') as infile:
        return infile.read()


def main():
    setup(
        name='mvdcommon',
        author="BARS Group",
        description='Общая кодовая база для проектов БЦ РЖД',
        url="https://stash.bars-open.ru/projects/EDURZHD/repos/mvd_medicine_common",
        classifiers=[
            'Intended Audience :: Developers',
            'Environment :: Web Environment',
            'Natural Language :: Russian',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Development Status :: 3 - Alpha',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3.6',
            'Programming Language :: Python :: 3.7',
            'Framework :: Django :: 2.2',
        ],
        package_dir={'': 'src'},
        packages=find_packages('src'),
        include_package_data=True,
        install_requires=tuple(_get_requirements('requirements/base.txt')),
        set_build_info=Path(__file__).parent.joinpath('src', 'mvdcommon'),
    )


if __name__ == '__main__':
    main()
