# coding: utf-8
from retry import retry
import pika


@retry(pika.exceptions.AMQPConnectionError, delay=5, jitter=5)
def consume(host, queue, user, password, callback):
    """
    Прослушивание канала связи с RabbiMQ и получение сообщений.
    В случае разрыва соединения из-за AMQPConnectionError, повторное
    подключение через 'delay' секунд.
    """
    connection = pika.BlockingConnection(
        pika.ConnectionParameters(
            host=host,
            credentials=pika.credentials.PlainCredentials(
                user, password
            )
        )
    )
    channel = connection.channel()
    channel.queue_declare(queue=queue, durable=True, exclusive=False)

    channel.basic_qos(prefetch_count=1)
    channel.basic_consume(queue=queue, on_message_callback=callback)
    try:
        channel.start_consuming()
    # Не восстанавливаем соединения закрытые сервером
    except pika.exceptions.ConnectionClosedByBroker:
        pass
